@@ -1739,6 +1739,29 @@ def df_graph_telegram_features (DiG, nodes_participants_df):
     df_graph_features["neighbours"] = neighbours_names
     return df_graph_features
 
+def graph_json_values_telegram(df_connections, data_graph_structure):
+
+    data = {}
+    data['nodes'] = []
+    for i in range(len(data_graph_structure)):
+      
+      data['nodes'].append({
+          'screen_name': data_graph_structure["screen_name"].iloc[i],
+          'community': str(data_graph_structure["community"].iloc[i]),
+          "community_degree_mean": float(data_graph_structure["community_degree_mean"].iloc[i])
+      })
+      
+    data['edges'] = []
+    for i in range(len(df_connections)):
+        if(df_connections["screen_name_mention"].iloc[i] != "Empty"):        
+            data['edges'].append({
+              'screen_name': df_connections["screen_name"].iloc[i],
+              'screen_name_mention': df_connections["screen_name_mention"].iloc[i],
+              'iteration': str(df_connections["iteration"].iloc[i])
+            })
+      
+    return data
+
 ###----------------------Contextual Analysis Telegram -----------------------###
 def detectLanguge(msg):
     lan=[]
